@@ -628,7 +628,10 @@ def get_always_tests_azure():
     print("getting azure tests set to always run")
     count = 0
     tests = ""
+    print(azurealwaysrunset)
     for testName in azurealwaysrunset:
+        print("here")
+        print(testName)
         count = count + 1
         if encodetests == "true":
             testName = testName.encode("unicode_escape").decode()
@@ -643,8 +646,11 @@ def get_always_tests_azure():
             testName = testName.replace("=", "\=")
             testName = testName.replace("!", "\!")
             testName = testName.replace("~", "\~")
-        
+            print(testName)
+        print("here2")
         tests = tests + testseparator + prefixtest + testName + postfixtest
+        print(tests)
+        print("here3")
     return tests
 
 
@@ -1990,8 +1996,10 @@ def runtestswithappsurify(*args):
                         alwaysrunset = [x.strip() for x in alwaysrun.split(',')]
                 if argv[k] == "--azurealwaysrun":
                     azurealwaysrun = argv[k + 1]
+                    print("setting azurealwaysrun")
                     if azurealwaysrun.lower() != "none":
                         azurealwaysrunset = [x.strip() for x in azurealwaysrun.split(',')]
+                        print(azurealwaysrunset)
                 if argv[k] == "--runcommand":
                     commandset = argv[k + 1]
                     startrunall = argv[k + 1]
@@ -2260,6 +2268,7 @@ def runtestswithappsurify(*args):
                     )
                 # print (f'##vso[task.setvariable variable={azurefilter}{azure_variable}{variable_num}]{testsrun}')
             else:
+                azurealwaysruntestsformatted = get_always_tests_azure()
                 if azurefilter != "":
                     if (
                         azurefilter.endswith("&") is False
@@ -2268,10 +2277,11 @@ def runtestswithappsurify(*args):
                         azurefilter = azurefilter + "&"
                 if azurevariablenum == 0:
                     print(
-                        f"##vso[task.setvariable variable={azure_variable}]{azurefilter}({testsrun})"
+                        f"##vso[task.setvariable variable={azure_variable}]{azurefilter}({testsrun}){azurealwaysruntestsformatted}"
                     )
                 azuresets = []
-                azurealwaysruntestsformatted = get_always_tests_azure()
+                
+                print(azurealwaysruntestsformatted)
                 while len(testsrun) > max_length:
                     split_string = testsrun.find("|Name=", max_length)
                     setval = testsrun[:split_string]
@@ -2287,7 +2297,7 @@ def runtestswithappsurify(*args):
                 if testsrun.startswith("|"):
                     testsrun = testsrun[1:]
                 print(
-                    f"##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}({testsrun}){azurealwaysruntestsformatted}"
+                    f"##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}({testsrun})"
                 )
                 testsettoappend = azurefilter + "(" + testsrun + ")"
                 azuresets.append(testsettoappend)
